package geometrie;
/**
 * Carre est la calsse qui implémente les carrés.
 *
 * Les carrés sont des figures gémoétriques possèdant quatre côté égaux
 * et des angles droit à chaque sommet.
 *
 * Ce sont aussi de manière équivalante des polygone régulier à quatre cotés.
 */
public class Carre extends PolygoneRegulier {
	private double taille;
	private double rotation;
	private Point positionCentre;

	/**
	 * Initialise les champs de la classe.
	 * 
	 * @param taille La taille du carré.
	 * @param rotation L'angle de rotation du carré.
	 * @param positionCentre La position du centre du carré.
	 */	
	private void init( double taille, double rotation, Point positionCentre ){
		this.taille = taille;
		this.rotation = rotation;
		this.positionCentre = new Point( positionCentre );
	}

	/**
	 * Constructeur de la classe
	 * 
	 * @param taille La taille du carré.
	 * @param rotation L'angle de rotation du carré.
	 * @param positionCentre La position du centre du carré.
	 */	
	public Carre( double taille, double rotation, Point positionCentre ){
		super( 4, rotation, positionCentre, (java.lang.Math.sqrt(2)/2.0)*taille );
		this.init( taille, rotation, positionCentre );
	}	

	/**
	 * Constructeur par recopie.
	 * 
	 * @param carre Le carré à recopier.
	 */	
	public Carre( Carre carre ){
		super( carre );
		this.init( carre.taille, carre.rotation, carre.positionCentre );
	}	
}
