package geometrie;
import java.util.*;
/**
 * La classe exemple définit des exemples d'utilisation de la librairies
 * géométrie.
 */
public class Exemples{
	/**
	 * Fonction qui execute l'ensemble des exemples.
	 *
	 * @param args entrees du programme. Elle ne sont pas utilisées.
	 */
	public static void main(String [] args){
		System.out.println("Ce programme donne quelques exemples d'utilisation de la librairies géométrie.");

		exempleVecteur();
		System.out.println("");
		System.out.println("");

		exemplePoint();
		System.out.println("");
		System.out.println("");

		exempleFigures();
	}

	/**
	 * Quelques exemples d'utilisation des vecteurs.
	 */
	public static void exempleVecteur(){
		System.out.println("Utilisation des vecteurs :");
		System.out.println("--------------------------");
		Vecteur vecteur1 = new Vecteur(1.0,2.0);
		Vecteur vecteur2 = new Vecteur(3.0,4.0);

		double norme = vecteur2.norme();
		System.out.println("Norme du vecteur (3,4) :" + norme );

		double scalaire = vecteur1.produitScalaire( vecteur2 );
		System.out.println("Produit scalaire entre (1,2) et (3,4) :" + scalaire );

		double vectoriel = vecteur1.produitVectoriel( vecteur2 );
		System.out.println("Produit vectoriel entre (1,2) et (3,4) :" + vectoriel );

		double angle = vecteur1.angle(vecteur2);
		System.out.println("Angle entre les vecteurs (1,2) et (3,4) :" + angle );

		double tetha = java.lang.Math.PI/3;
		Vecteur x = new Vecteur(1,0);
		Vecteur y = new Vecteur(0,1);
		Vecteur rotX = x.rotation( tetha ); 
		Vecteur rotY = y.rotation( tetha );
		System.out.println("Rotation du vecteur (1,0) d'angle Pi/3 : (" + rotX.getX()  + ", " + rotX.getY() + ")"  );
		System.out.println("Rotation du vecteur (0,1) d'angle Pi/3 : (" + rotY.getX()  + ", " + rotY.getY() + ")"  );
	}

	/**
	 * Quelques exemples d'utilisation des Points.
	 */
	public static void exemplePoint(){
		System.out.println("Utilisation des Points :");
		System.out.println("------------------------");
		Point p1 = new Point(1,2);	
		Point p2 = new Point(-3,5);

		Vecteur diff = p1.moins(p2);
		System.out.println("Vecteur Point(1,2) - Point(-3,5): " + diff.getX() + ", "  + diff.getY() );

		p2.translater( new Vecteur(1,-2) );
		System.out.println("Translation du Point (-3,5) de vecteur (1,-2) : " + p2.getX() + ", "  + p2.getY() );
		
		Point origine = new Point( 1,-1 );
		Point chgRp = p1.changementDeRepere( java.lang.Math.PI/2, origine );
		System.out.println("expression de (1,2) dans le repere de rotation Pi/2 et de centre (1,-1) : " + chgRp.getX() + ", " + chgRp.getY()  );		

		Point posRp = p1.positionnementDansLeRepere( java.lang.Math.PI/2, origine );
		System.out.println("Positionnement de (1,2) dans le repere de rotation Pi/2 et de centre (1,-1) : " + posRp.getX() + ", " + posRp.getY()  );		
		
	}


	/**
	 * Quelques exemples d'utilisation des Figures.
	 */
	public static void exempleFigures(){
		System.out.println("Utilisation des Figures :");
		System.out.println("-------------------------");
		System.out.println("");

		exemplePolygone();
		System.out.println("");

		exemplePolygoneConvexe();
		System.out.println("");

		exemplePolygoneRegulier();
		System.out.println("");

		exempleTraingle();
		System.out.println("");

		exempleCarre();
		System.out.println("");

		exempleRectangle();
		System.out.println("");

		exempleLosange();
	}

	
	/**
	 * Quelques exemples d'utilisation de polygones.
	 */
	public static void exemplePolygone(){
		System.out.println("polygone convexe :");
		System.out.println("- - - - - - - - - -");
		List<Point> sommets = new LinkedList<Point>();
		sommets.add( new Point(1,0) );
		sommets.add( new Point(5,-1) );
		sommets.add( new Point(5,3) );
		sommets.add( new Point(3,1) );
		sommets.add( new Point(2,3) );
		Polygone poly = new Polygone(sommets);
		System.out.println( "poly convexe : "+ geometrie.PolygoneConvexe.isConvexe(poly));
		Point p1,p2,p3,p4,p5;
		p1 = new Point(3,-1);
		p2 = new Point(4,0);
		p3 = new Point(3,2);
		p4 = new Point(2,2);
		p5 = new Point(1,1);
		System.out.println( "(3,-1) est à l'interieur de poly: " + poly.isInside(p1)  );
		System.out.println( "(4,0) est à l'interieur de poly: " + poly.isInside(p2)  );
		System.out.println( "(3,2) est à l'interieur de poly: " + poly.isInside(p3)  );
		System.out.println( "(2,2) est à l'interieur de poly: " + poly.isInside(p4)  );
		System.out.println( "(1,1) est à l'interieur de poly: " + poly.isInside(p5)  );
	}
	/**
	 * Quelques exemples d'utilisation de polygones convexe.
	 */
	public static void exemplePolygoneConvexe(){
		System.out.println("polygone non convexe :");
		System.out.println("- - - - - - - - - -  -");
		List<Point> sommets = new LinkedList<Point>();
		sommets.add( new Point(2,-1) );
		sommets.add( new Point(6,0) );
		sommets.add( new Point(3,4) );
		sommets.add( new Point(1,2) );
		Polygone polyCon = new PolygoneConvexe(sommets);
		System.out.println( "polyCon convexe : "+ geometrie.PolygoneConvexe.isConvexe(polyCon));

		Point p1,p2,p3,p4,p5;
		p1 = new Point(3,-1);
		p2 = new Point(4,0);
		p3 = new Point(3,2);
		p4 = new Point(2,2);
		p5 = new Point(1,1);
		System.out.println( "(3,-1) est à l'interieur de polyCon: " + polyCon.isInside(p1)  );
		System.out.println( "(4,0) est à l'interieur de polyCon: " + polyCon.isInside(p2)  );
		System.out.println( "(3,2) est à l'interieur de polyCon: " + polyCon.isInside(p3)  );
		System.out.println( "(2,2) est à l'interieur de polyCon: " + polyCon.isInside(p4)  );
		System.out.println( "(1,1) est à l'interieur de polyCon: " + polyCon.isInside(p5)  );
	}

	/**
	 * Quelques exemples d'utilisation de polygone réguliers.
	 */
	public static void exemplePolygoneRegulier(){
		System.out.println("polygone régulier :");
		System.out.println("- - - - - - - - - -");
		System.out.println("Exemples à écrire en exercice.");
	}

	/**
	 * Quelques exemples d'utilisation de triangle.
	 */
	public static void exempleTraingle(){
		System.out.println("Triangle :");
		System.out.println("- - - - - - - - - -");
		System.out.println("Exemples à écrire en exercice.");
	}

	/**
	 * Quelques exemples d'utilisation de carré.
	 */
	public static void exempleCarre(){
		System.out.println("Carré :");
		System.out.println("- - - - - - - - - -");
		System.out.println("Exemples à écrire en exercice.");
	}

	/**
	 * Quelques exemples d'utilisation de rectangle.
	 */
	public static void exempleRectangle(){
		System.out.println("Rectangle :");
		System.out.println("- - - - - - - - - -");
		System.out.println("Exemples à écrire en exercice.");
	}

	/**
	 * Quelques exemples d'utilisation de losange.
	 */
	public static void exempleLosange(){
		System.out.println("Losange :");
		System.out.println("- - - - - - - - - -");
		System.out.println("Exemples à écrire en exercice.");
	}


}
