package geometrie;
import java.util.*;
/**
 * Losange est la calsse qui implémente les losanges.
 *
 * Les losanges sont des figures gémoétriques possèdant quatre côté égaux.
 */
public class Losange extends PolygoneConvexe {
	private double largeur;
	private double hauteur;
	private Point positionCentre;
	private double rotation;

	/**
	 * Initialise les champs de la classe.
	 * 
	 * @param largeur La largeur du losange.
	 * @param hauteur La hauteur du losange.
	 * @param positionCentre La position du centre du losange.
	 * @param rotation L'angle de rotation du losange.
	 */	
	private void init( double largeur, double hauteur, Point positionCentre, double rotation ){
		this.largeur = largeur;
		this.hauteur = hauteur;
		this.positionCentre = new Point( positionCentre );
		this.rotation  = rotation ;
	}

	/**
	 * Renvoie la liste des sommets de la frontière du lasange.
	 * 
	 * @param largeur La largeur du losange.
	 * @param hauteur La hauteur du losange.
	 * @param positionCentre La position du centre du losange.
	 * @param rotation L'angle de rotation du losange.
	 * @return La liste des sommets codant la frontière du losange.
	 */	
	private static List<Point> getList( double largeur, double hauteur, Point positionCentre, double rotation ){
		List<Point> sommets = new LinkedList<Point>();
		sommets.add(
			(new Point( -largeur/2.0, 0.0 )).positionnementDansLeRepere( rotation, positionCentre )
		);
		sommets.add(
			(new Point( 0.0, -hauteur/2.0 )).positionnementDansLeRepere( rotation, positionCentre )
		);
		sommets.add(
			(new Point( +largeur/2.0, 0.0 )).positionnementDansLeRepere( rotation, positionCentre )
		);
		sommets.add(
			(new Point( 0.0, +hauteur/2.0 )).positionnementDansLeRepere( rotation, positionCentre )
		);
		return sommets;
	}

	/**
	 * Constructeur de la classe
	 * 
	 * @param largeur La largeur du losange.
	 * @param hauteur La hauteur du losange.
	 * @param positionCentre La position du centre du losange.
	 * @param rotation L'angle de rotation du losange.
	 */	
	public Losange( double largeur, double hauteur, Point positionCentre, double rotation ){
		super( getList(largeur,hauteur,positionCentre, rotation) );
		this.init(largeur,hauteur,positionCentre, rotation);	
	}

	/**
	 * Constructeur par recopie.
	 * 
	 * @param losange Le losange à recopier.
	 */	
	public Losange( Losange losange ){
		super( losange.sommets );
		this.init( losange.largeur, losange.hauteur, losange.positionCentre, losange.rotation);
	}
}
