package geometrie;
import java.util.*;

/**
 * Polygone est une classe qui implémentante les polygones.
 * Un polygone est une figure géométrique.
 * Elle est constituée d'un ensemble de point du plan connexe dont le bord ou la 
 * frontière est une ligne brisée.
 * Les segments de la ligne brisée sont apellés les côtés du polygone.
 * <p>
 * Généralement la ligne brisée qui défini la frontière du polygone est
 * définit par une liste de point u1, ..., un de façons à ce que (u1,u2), 
 * (u2,u3), ... ,(un-1,un),(un,u1) constitue les cote du polygone.
 */
public class Polygone implements FigureGeometrique {
	protected List<Point> sommets;
	/**
	 * Constructueur de la classe Polygone
	 *
	 * @param sommets La liste des sommets définissant le bord d'un polygone. 
	 *                Cette liste ne doit pas contnir de doublan, chaque paires
	 *                de sommets consécutifs doit être les sommet d'un côté du
     *                polygone.
     *                La ligne ne doit pas se couper elle même.
	 *
	 */
	public Polygone( List<Point> sommets ){
		this.sommets = new LinkedList<Point>();
		for (Point point : sommets) {
			this.sommets.add( new Point(point) );
		}
	}

	/**
	 * Constructueur par recopie
	 *
	 * @param polygone le polygone à recopier
	 */
	public Polygone( Polygone polygone ){
		this( polygone.sommets );
	}

	/**
     * Teste si un point est à l'interieur de la figure.
	 *
	 * @param point Le point à tester. 
	 * @return Vraie si le point est à l'intérieur de la figure.
	 *         Faux sinon.
	 */
	public boolean isInside( Point point ){
		Point p1;
		float angle = 0;
		Iterator it = this.sommets.iterator();
		Point p2 = (Point) (it.next());
		while( it.hasNext() ){
			p1 = p2;
			p2 = (Point) (it.next());
			angle += ( new Vecteur(point,p1) ).angle( new Vecteur(point,p2) );
		}
		p1 = p2;
		p2 = ((LinkedList<Point>) this.sommets).getFirst();
		angle += ( new Vecteur(point,p1) ).angle( new Vecteur(point,p2) );
		if( ( angle < java.lang.Math.PI ) && ( angle > -java.lang.Math.PI ) ) return false;
		return true;
	}
}
