package geometrie;
import java.util.*;
/**
 * PolygoneRegulier est la classe qui implémente les polygones régulier.
 *
 * Un polygone régulier est un polygone convexe dons les sommets sont inscrit
 * dans un cercle et dont les côtés sont de même tailles.
 *
 */
public class PolygoneRegulier extends PolygoneConvexe {
	private int nombreArretes;
	private double rotation;
	private Point positionCentre;
	private double rayon;

	/**
	 * Initialise les champs de la classe PolygoneRegulier.
     *
	 * @param nombreArretes Nomre de côté du polygone convexe
	 * @param rotation Angle de rotation autour de positionCentre a effectuer 
	 *        au polygone regulier horizontal pour obtenir le polygone regulier
	 *        demande
	 * @param positionCentre Position dans le plan du centre du polygone régulier
	 * @param rayon Taille du polygone régilier ( le polygone régulier est inscrit 
	 *        dans un cercle de rayon <code>rayon</code>.
	 */
	private void initialisation(
		int nombreArretes, double rotation,	Point positionCentre, double rayon
	){
		this.nombreArretes = nombreArretes;
		this.rotation = rotation;
		this.positionCentre = new Point( positionCentre );
		this.rayon = rayon;
	}

	/**
	 * Créer à partir du nombre de côté, du rayon, de la position et de 
	 * l'orientation du polygonne régulier, la liste de sommet qui constitue la
	 *  frontière du polygôn,e régulier.
     *
	 * @param nombreArretes Nomre de côté du polygone convexe
	 * @param rotation Angle de rotation autour de positionCentre a effectuer 
	 *        au polygone regulier horizontal pour obtenir le polygone regulier
	 *        demande
	 * @param positionCentre Position dans le plan du centre du polygone régulier
	 * @param rayon Taille du polygone régilier ( le polygone régulier est inscrit 
	 *        dans un cercle de rayon <code>rayon</code>.
	 * @return La liste des sommets du polygoneRegulier.
	 */
	private static List<Point> obtenirForme(
		int nombreArretes, double rotation, Point positionCentre, double rayon
	){
		double pas = ( 2 * java.lang.Math.PI ) / nombreArretes;
		List<Point> forme = new LinkedList<Point>();
		for( int i = 0; i< nombreArretes -1; i++ ){
			forme.add(
				new Point(
					rayon * java.lang.Math.cos( i*pas + rotation ) + positionCentre.getX(),
					rayon * java.lang.Math.sin( i*pas + rotation ) + positionCentre.getY()
				)
			); 
		}
		return forme;
	}

	/**
	 * Constructeur de la classe.
	 *
	 * @param nombreArretes Nomre de côté du polygone convexe
	 * @param rotation Angle de rotation autour de positionCentre a effectuer 
	 *        au polygone regulier horizontal pour obtenir le polygone regulier
	 *        demande.
	 * @param positionCentre Position dans le plan du centre du polygone régulier
	 * @param rayon Taille du polygone régulier ( le polygone régulier est inscrit 
	 *        dans un cercle de rayon <code>rayon</code>.
	 */
	public PolygoneRegulier( int nombreArretes, double rotation, Point positionCentre, double rayon ){
		super( obtenirForme(nombreArretes, rotation, positionCentre, rayon) );
		this.initialisation(nombreArretes, rotation, positionCentre, rayon);
	}

	/**
	 * Constructeur par recopie de la classe.
	 *
	 * @param polygoneRegulier Le polygone régulier à recopier.
	 */
	public PolygoneRegulier( PolygoneRegulier polygoneRegulier ){
		super( polygoneRegulier );
		this.initialisation(polygoneRegulier.nombreArretes, polygoneRegulier.rotation, polygoneRegulier.positionCentre, polygoneRegulier.rayon);
	}
}
