package geometrie;
import java.util.*;
/**
 * rectangle est la classe qui implémente les rectangles.
 *
 * Les rectangles sont des figures gémoétriques possèdant quatre côtés et des
 * droit à chacun de ses sommets.
 */
public class Rectangle extends PolygoneConvexe {
	private double largeur;
	private double hauteur;
	private Point positionCentre;
	private double rotation;
	
	/**
	 * Initialise les champs de la classe.
	 * 
	 * @param largeur La largeur du rectangle.
	 * @param hauteur La hauteur du rectangle.
	 * @param positionCentre La position du centre du rectangle.
	 * @param rotation L'angle de rotation du rectangle.
	 */	
	private void init( double largeur, double hauteur, Point positionCentre, double rotation ){
		this.largeur = largeur;
		this.hauteur = hauteur;
		this.positionCentre = new Point( positionCentre );
		this.rotation  = rotation ;
	}

	/**
	 * Renvoie la liste des sommets de la frontière du lasange.
	 * 
	 * @param largeur La largeur du rectangle.
	 * @param hauteur La hauteur du rectangle.
	 * @param positionCentre La position du centre du rectangle.
	 * @param rotation L'angle de rotation du rectangle.
	 * @return La liste des sommets codant la frontière du rectangle.
	 */	
	private static List<Point> getList( double largeur, double hauteur, Point positionCentre, double rotation ){
		List<Point> sommets = new LinkedList<Point>();
		sommets.add(
			(new Point( -largeur/2.0, -hauteur/2.0 )).positionnementDansLeRepere( rotation, positionCentre )
		);
		sommets.add(
			(new Point( +largeur/2.0, -hauteur/2.0 )).positionnementDansLeRepere( rotation, positionCentre )
		);
		sommets.add(
			(new Point( +largeur/2.0, +hauteur/2.0 )).positionnementDansLeRepere( rotation, positionCentre )
		);
		sommets.add(
			(new Point( -largeur/2.0, +hauteur/2.0 )).positionnementDansLeRepere( rotation, positionCentre )
		);
		return sommets;
	}

	/**
	 * Constructeur de la classe
	 * 
	 * @param largeur La largeur du losange.
	 * @param hauteur La hauteur du losange.
	 * @param positionCentre La position du centre du losange.
	 * @param rotation L'angle de rotation du losange.
	 */	
	public Rectangle( double largeur, double hauteur, Point positionCentre, double rotation ){
		super( getList(largeur,hauteur,positionCentre, rotation) );
		this.init(largeur,hauteur,positionCentre, rotation);	
	}

	/**
	 * Constructeur par recopie.
	 * 
	 * @param rectangle Le rectangle à recopier.
	 */	
	public Rectangle( Rectangle rectangle ){
		super( rectangle.sommets );
		this.init( rectangle.largeur, rectangle.hauteur, rectangle.positionCentre, rectangle.rotation);
	}
}
