package geometrie;
/**
 * La calsse segment implémente les segments.
 *
 * Un segment est défini à l'aide de deux points appelé extrémités du segment.
 * Un segment est l'ensemble des barycentres associés aux extrémités du segment
 * et à coefficient positifs.
 */
public class Segment implements FigureGeometrique {
	private Point p1;
	private Point p2;

	/**
	 * Constructeur par recopier
	 *
	 * @param segment Le segment à recopier.
	 */
	public Segment( Segment segment ){
		this.p1 = new Point( segment.p1 );
		this.p2 = new Point( segment.p2 );
	}

	/**
	 * Constructuer de la classe à l'aide des deux extrémités du segment.
	 *
	 * @param p1 La première extrémité du segment.
	 * @param p2 La deuxième extrémité du segment.
	 */
	public Segment( Point p1, Point p2 ){
		this.p1 = new Point(p1);
		this.p2 = new Point(p2);
	}

	/**
	 * Renvoi le vecteur d'origine la première extrémité du segment et de fin 
     * la deuxième extrémité.
	 *
	 * @return Le vecteur représeant le segment.
	 */
	public Vecteur getVecteur(){
		return new Vecteur( this.p1, this.p2 );
	}

	/**
	 * Renvoi la première extrémité du segment.
	 *
	 * @return Le point associé à la première extrmémité du segment.
	 */
	public Point getPoint1(){
		return new Point(this.p1);
	}

	/**
	 * Renvoi la deuxième extrémité du segment.
	 *
	 * @return Le point associé à la deuxième extrmémité du segment.
	 */
	public Point getPoint2(){
		return new Point(this.p2);
	}

	/**
	 * Vérifie si un point donné appartient au segment.
	 *
	 * @param point Le point qui fera l'objet du test.
	 */
	public boolean isInside( Point point ){
		return
			(new Droite( this )).isInside( point ) &&
			(this.getVecteur().produitScalaire( new Vecteur( this.p1, point ) )  >= 0 ) &&
			(this.getVecteur().produitScalaire( new Vecteur( this.p2, point ) )  <= 0 );
	}
}
